@@ -43,6 +43,26 @@ authenticate_sb = function(username, password){
 		stop('Unable to authenticate to SB. Check username and password')
 	}
 	
+	token_url <- pkg.env$token_url
+	
+	token <- POST(token_url, 
+								body = list(
+									client_id = pkg.env$keycloak_client_id,
+									grant_type = "password",
+									username = username,
+									password = password
+								), encode = "form")
+	
+	if(!token$status_code == 200) {
+		
+		warning('Unable to authenticate to SB cloud. Standard login is available.')
+		
+	} else {
+	
+		set_keycloak_env(token)
+		
+	}
+	
 	attributes(h) <- c(attributes(h), list(birthdate=Sys.time()))
 	pkg.env$session  = h
 	pkg.env$username = username
@@ -50,6 +70,12 @@ authenticate_sb = function(username, password){
 	invisible(h)
 }
 
+set_keycloak_env <- function(token_resp) {
+	pkg.env$keycloak_token <- jsonlite::fromJSON(rawToChar(token_resp$content))
+	
+	pkg.env$keycloak_expire <- Sys.time() + pkg.env$keycloak_token$expires_in
+}
+
 #' Read in a password from the user
 #' 
 #' Uses the RStudio pop-up password window if available
@@ -65,4 +91,25 @@ readPassword <- function(prompt) {
 	}
 	return (pass)
 }
-globalVariables('.rs.askForPassword')
\ No newline at end of file
+
+globalVariables('.rs.askForPassword')
+
+get_refresh_token <- function() {
+	token <- pkg.env$keycloak_token$refresh_token
+	
+	if(is.null(token)) {
+		stop("no token found, must call athenticate_sb()")
+	}
+	
+	token
+}
+
+get_access_token <- function() {
+	token <- pkg.env$keycloak_token$access_token
+	
+	if(is.null(token)) {
+		stop("no token found, must call athenticate_sb()")
+	}
+	
+	token
+}
\ No newline at end of file
